Gui Features in OpenCV {#tutorial_py_table_of_contents_gui}
======================

-   @subpage tutorial_py_image_display

    Learn to load an
    image, display it and save it back

-   @subpage tutorial_py_video_display

    Learn to play videos,
    capture videos from Camera and write it as a video

-   @subpage tutorial_py_drawing_functions

    Learn to draw lines,
    rectangles, ellipses, circles etc with OpenCV

-   @subpage tutorial_py_mouse_handling

    Draw stuffs with your
    mouse

-   @subpage tutorial_py_trackbar

    Create trackbar to
    control certain parameters
